<?php
/**
 * Typography Panel customize settings.
 *
 * @package    Community_Builder
 * @subpackage Customizer
 * @copyright  Copyright (c) 2018, Brajesh Singh
 * @license    https://www.gnu.org/licenses/gpl.html GNU Public License
 * @author     Brajesh Singh
 */

// Do not allow direct access over web.
defined( 'ABSPATH' ) || exit;

/**
 * Typography panel helper.
 */
class CB_Customize_Panel_Typography {

	/**
	 * Panel id.
	 *
	 * @var string
	 */
	private $panel = 'cb_typography';

	/**
	 * CB_Customize_Panel_Typography constructor.
	 */
	public function __construct() {
		// hook to cb customizer.
		add_filter( 'cb_customizer_sections', array( $this, 'add_sections' ) );
	}

	/**
	 * Add sections for this panel.
	 *
	 * @param array $sections sections.
	 *
	 * @return array
	 */
	public function add_sections( $sections ) {

		$new_sections = $this->get_sections();

		return array_merge( $sections, $new_sections );
	}

	/**
	 * Get all sections for this panel.
	 *
	 * @return array
	 */
	public function get_sections() {

		$panel = $this->panel;

		$typography_sections = array();

		/**
		 * Global
		 */
		$typography_sections['base-font'] = array(
			'panel'   => $panel,
			'title'   => __( 'Global Settings', 'community-builder' ),
			'options' => array(
				'base-font-settings' => CB_Customize_Setting_Builder::get_typography_settings( 'base', __( 'Base', 'community-builder' ) ),
			),
		);

		/**
		 * Site Title & Tagline
		 */
		$typography_sections['font-site-title-tagline'] = array(
			'panel'   => $panel,
			'title'   => __( 'Site Title &amp; Tagline', 'community-builder' ),
			'options' => array(
				'site-title-font-settings'   => CB_Customize_Setting_Builder::get_typography_settings( 'site-title', __( 'Site Title', 'community-builder' ) ),
				'site-tagline-font-settings' => CB_Customize_Setting_Builder::get_typography_settings( 'site-tagline', __( 'Tagline', 'community-builder' ), '', 'cb_is_tagline_visible' ),
			),
		);

		/**
		 * Text Headers
		 */
		$typography_sections['font-page-headers'] = array(
			'panel'   => $panel,
			'title'   => __( 'Page Header', 'community-builder' ),
			'options' => array(
				'page-header-title-font-settings'   => CB_Customize_Setting_Builder::get_typography_settings( 'page-header-title', __( 'Title', 'community-builder' ) ),
				'page-header-content-font-settings' => CB_Customize_Setting_Builder::get_typography_settings( 'page-header-content', __( 'Description', 'community-builder' ) ),
				'page-header-meta-font-settings'    => CB_Customize_Setting_Builder::get_typography_settings( 'page-header-meta', __( 'Meta', 'community-builder' ) ),
			),
		);

		/**
		 * Footer
		 */
		$typography_sections['font-footer'] = array(
			'panel'   => $panel,
			'title'   => __( 'Footer', 'community-builder' ),
			'options' => array(
				'footer-font-settings'              => CB_Customize_Setting_Builder::get_typography_settings( 'footer', __( 'Footer Content', 'community-builder' ) ),
				'footer-widget-title-font-settings' => CB_Customize_Setting_Builder::get_typography_settings( 'footer-widget-title', __( 'Widget Title', 'community-builder' ) ),
				'footer-widget-font-settings'       => CB_Customize_Setting_Builder::get_typography_settings( 'footer-widget', __( 'Widget Content', 'community-builder' ) ),
				'site-copyright-font-settings'      => CB_Customize_Setting_Builder::get_typography_settings( 'site-copyright', __( 'Site Copyright', 'community-builder' ) ),
			),
		);

		/**
		 * Filter the definitions for the controls in the Typography panel of the Customizer.
		 *
		 * @since 1.0.0.
		 *
		 * @param array $typography_sections The array of definitions.
		 */
		$typography_sections = apply_filters( 'cb_customizer_typography_sections', $typography_sections );

		return $typography_sections;

	}

} // end of class.

new CB_Customize_Panel_Typography();
